ReasonCode

Enum ReasonCode 

#[non_exhaustive]
pub enum ReasonCode {
Show 30 variants Unconditional, AllChecksPassed, CapabilityPresent, CapabilityMissing, IssuerMatch, IssuerMismatch, Revoked, Expired, InsufficientTtl, IssuedTooLongAgo, RoleMismatch, ScopeMismatch, ChainTooDeep, DelegationMismatch, AttrMismatch, MissingField, RecursionExceeded, ShortCircuit, CombinatorResult, WorkloadMismatch, WitnessQuorumNotMet, SignerTypeMatch, SignerTypeMismatch, ApprovalRequired, ApprovalGranted, ApprovalExpired, ApprovalAlreadyUsed, ApprovalRequestMismatch, AssuranceMet, AssuranceInsufficient,
}
Machine-readable reason code for stable logging and alerting.

These codes are designed to be stable across versions for use in monitoring dashboards, alerting rules, and audit queries.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unconditional

Unconditional allow/deny (True/False expressions).



AllChecksPassed

All checks in a policy passed.



CapabilityPresent

Required capability is present.



CapabilityMissing

Required capability is missing.



IssuerMatch

Issuer matches expected value.



IssuerMismatch

Issuer does not match expected value.



Revoked

Attestation has been revoked.



Expired

Attestation has expired.



InsufficientTtl

Remaining TTL is below required threshold.



IssuedTooLongAgo

Attestation was issued too long ago.



RoleMismatch

Role does not match expected value.



ScopeMismatch

Scope (repo, ref, path, env) does not match.



ChainTooDeep

Delegation chain exceeds maximum depth.



DelegationMismatch

Delegator does not match expected value.



AttrMismatch

Custom attribute does not match expected value.



MissingField

Required field is missing from context.



RecursionExceeded

Expression recursion limit exceeded.



ShortCircuit

Short-circuit evaluation in And/Or.



CombinatorResult

Result from And/Or/Not combinator.



WorkloadMismatch

Workload claim does not match expected value.



WitnessQuorumNotMet

Witness quorum was not met.



SignerTypeMatch

Signer type matches expected value.



SignerTypeMismatch

Signer type does not match expected value.



ApprovalRequired

Policy ApprovalGate determined human approval is needed.



ApprovalGranted

Approval attestation was valid and matched.



ApprovalExpired

Approval request TTL expired.



ApprovalAlreadyUsed

Approval JTI already used (replay attempt).



ApprovalRequestMismatch

Approval scope hash doesn’t match the current request.



AssuranceMet

Assurance level meets or exceeds the minimum requirement.



AssuranceInsufficient

Assurance level is below the minimum requirement.